%define dlname Botan

%define api     3
%define major   7
%define libname %mklibname botan %{api} %{major}
%define devname %mklibname botan %{api} -d

Name:           botan3
Version:        3.7.1
Release:        %mkrel 2
Summary:        Crypto and TLS for Modern C++
Group:          System/Libraries
License:        BSD
URL:            https://botan.randombit.net/
Source0:        https://botan.randombit.net/releases/%{dlname}-%{version}.tar.xz#!/%{name}-%{version}.tar.xz

BuildRequires:  gcc-c++
BuildRequires:  graphviz
BuildRequires:  boost-devel
BuildRequires:  trousers-devel
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  python3dist(sphinx)
# For man page (rst2man)
BuildRequires:  python3dist(docutils)

Requires:       python3

Conflicts:      botan2 < 2.19.4-3

%description
Botan is a BSD-licensed crypto library written in C++. It provides a
wide variety of basic cryptographic algorithms, X.509 certificates and
CRLs, PKCS \#10 certificate requests, a filter/pipe message processing
system, and a wide variety of other features, all written in portable
C++. The API reference, tutorial, and examples may help impart the
flavor of the library. This is the current stable release branch 2.x
of Botan.


%package -n     %{libname}
Summary:        Library files for %{name}
Group:          System/Libraries
Requires:       %{name} >= %{version}-%{release}

%description -n %{libname}
The %{libname} package contains library files for %{name}.


%package -n     %{devname}
Summary:        Development files for %{name}
Group:          Development/C++
Requires:       %{name} = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
The %{devname} package contains libraries and header files for
developing applications that use %{name}.


%package        doc
Summary:        Documentation for %{name}
Group:          Documentation
BuildArch:      noarch

%description    doc
Documentation for %{name}.

This package contains HTML documentation for %{name}.


%package -n     python3-%{name}
Summary:        Python3 bindings for %{name}
Group:          Development/Python
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name}
This package contains the Python3 binding for %{name}.


%prep
%autosetup -p1 -n %{dlname}-%{version}

%py3_shebang_fix \
configure.py \
src/scripts/*.py \
src/python/*.py

%build
# we have the necessary prerequisites, so enable optional modules
%define enable_modules bzip2,zlib,boost,sqlite3,lzma,tpm

./configure.py \
        --distribution-info="%{_vendor} %{name} %{version}-%{release}" \
        --prefix=%{_prefix} \
        --libdir=%{_lib} \
        --docdir=%{_docdir} \
        --cc=gcc \
        --os=linux \
        --cpu=%{_arch} \
        --extra-cxxflags="%{build_cxxflags}" \
        --ldflags="%{build_ldflags}" \
        --enable-modules=%{enable_modules} \
        --with-python-versions=%{python3_version} \
        --with-sphinx \
        --enable-shared-library \
        --disable-static-library \
        --with-debug-info \
        --with-os-features=getrandom,getentropy

%make_build

%install
%make_install \
     INSTALL_CMD_EXEC="install -p -m 755" \
     INSTALL_CMD_DATA="install -p -m 644"

chmod 755 %{buildroot}%{python3_sitearch}/%{name}.py

find %{buildroot} -name '*.a' -delete

%check
%ifnarch %arm %ix86
LD_LIBRARY_PATH=%{buildroot}%{_libdir} ./botan-test
%endif

%files
%license license.txt
%{_bindir}/botan
%{_mandir}/man1/*

%files -n %{libname}
%license license.txt
%{_libdir}/libbotan-%{api}.so.%{major}{,.*}

%files -n %{devname}
%license license.txt
%{_includedir}/botan-%{api}/
%{_libdir}/libbotan-%{api}.so
%{_libdir}/pkgconfig/botan-%{api}.pc
%{_libdir}/cmake/Botan-%{version}/

%files doc
%license license.txt
%{_docdir}/botan-%{version}/

%files -n python3-%{name}
%license license.txt
%{python3_sitearch}/%{name}.py
%{python3_sitearch}/__pycache__/*


%changelog
* Thu Mar 06 2025 daviddavid <daviddavid> 3.7.1-2.mga10
+ Revision: 2161262
- rebuild for python 3.13

* Fri Feb 14 2025 daviddavid <daviddavid> 3.7.1-1.mga10
+ Revision: 2148745
- new version: 3.7.1
- now libmajor is 7

* Sun Oct 27 2024 daviddavid <daviddavid> 3.6.1-1.mga10
+ Revision: 2111347
- new version: 3.6.1

* Wed Oct 23 2024 daviddavid <daviddavid> 3.6.0-1.mga10
+ Revision: 2110537
- new version: 3.6.0
- now libmajor is 6

* Sun Apr 14 2024 daviddavid <daviddavid> 3.4.0-4.mga10
+ Revision: 2057184
- rebuild with fixed gcc-14.0.1-0.20240407.1.mga10 for arm regression

* Thu Apr 11 2024 daviddavid <daviddavid> 3.4.0-3.mga10
+ Revision: 2056600
- fix conflicting files with botan2 pkg

* Thu Apr 11 2024 daviddavid <daviddavid> 3.4.0-2.mga10
+ Revision: 2056469
- backport upstream patch to use std::span<> in X/Ed25519 constructors

* Thu Apr 11 2024 kekepower <kekepower> 3.4.0-1.mga10
+ Revision: 2056455
- Update to version 3.4.0
- now libmajor is 4

* Thu Feb 22 2024 daviddavid <daviddavid> 3.3.0-2.mga10
+ Revision: 2043236
- fix owner of cmake config files

* Thu Feb 22 2024 kekepower <kekepower> 3.3.0-1.mga10
+ Revision: 2043121
- Update lib major to 3
- Update to version 3.3.0

* Wed Dec 20 2023 daviddavid <daviddavid> 3.2.0-2.mga10
+ Revision: 2019940
- rebuild for py3.12

* Wed Nov 01 2023 daviddavid <daviddavid> 3.2.0-1.mga10
+ Revision: 2003244
- initial package botan3

